@@ -181,6 +181,8 @@ OC.L10N.register(
     "Calendar events with you" : "与您分享的日历事件",
     "Deck cards with you" : "与您分享的卡片",
     "No shared items with this contact" : "与该联系人无共享项目",
+    "This contact cannot be moved" : "此联系人无法移动",
+    "This contact cannot be grouped" : "此联系人无法分组",
     "Add contacts to groups" : "添加联系人到群组",
     "Move contacts to addressbook" : "移动联系人到通讯录",
     "Select groups" : "选择群组",
@@ -188,8 +190,6 @@ OC.L10N.register(
     "Selected contacts" : "已选择联系人",
     "Please note that only {count} of the {total} contacts can be added to a group" : "请注意，{total} 位联系人中只有 {count} 位可以添加到群组中",
     "Please note that only {count} of the {total} contacts can be moved" : "请注意，{total} 位联系人中只有 {count} 位可以移动。",
-    "This contact cannot be grouped" : "此联系人无法分组",
-    "This contact cannot be moved" : "此联系人无法移动",
     "Move" : "移动",
     "from {addressbook}" : "从 {addressbook}",
     "Confirm merging contacts" : "确认合并联系人",
@@ -254,6 +254,9 @@ OC.L10N.register(
     "Add contact in group" : "添加联系人到群组",
     "None" : "无",
     "Select option" : "选择选项",
+    "note" : "备注",
+    "email" : "电子邮件",
+    "send an email" : "发送邮件",
     "Personal dates" : "个人行程",
     "Add property of this type" : "为此类型添加属性",
     "Member" : "成员",
@@ -315,7 +318,7 @@ OC.L10N.register(
     "Prefix" : "前缀",
     "Suffix" : "后缀",
     "Nickname" : "昵称",
-    "Notes" : "说明",
+    "Notes" : "备注",
     "Website" : "网站",
     "Location" : "地点",
     "Federated Cloud ID" : "联合云 ID",
