@@ -181,6 +181,8 @@ OC.L10N.register(
     "Calendar events with you" : "與您分享的日曆活動",
     "Deck cards with you" : "與您分享的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "This contact cannot be moved" : "無法將此聯絡人移動",
+    "This contact cannot be grouped" : "無法將此聯絡人分組",
     "Add contacts to groups" : "添加增聯絡人到群組",
     "Move contacts to addressbook" : "將聯絡人移至地址簿",
     "Select groups" : "選擇群組",
@@ -188,8 +190,6 @@ OC.L10N.register(
     "Selected contacts" : "已選的聯絡人",
     "Please note that only {count} of the {total} contacts can be added to a group" : "請注意：在 {total} 個聯絡人中，只能將其中 {count} 個加入群組",
     "Please note that only {count} of the {total} contacts can be moved" : "請注意：在 {total} 個聯絡人中，只能將其中 {count} 個移動",
-    "This contact cannot be grouped" : "無法將此聯絡人分組",
-    "This contact cannot be moved" : "無法將此聯絡人移動",
     "Move" : "移動",
     "from {addressbook}" : "從 {addressbook}",
     "Confirm merging contacts" : "確認合併聯絡人",
@@ -254,6 +254,8 @@ OC.L10N.register(
     "Add contact in group" : "新增聯絡人到群組",
     "None" : "無",
     "Select option" : "選擇選項",
+    "note" : "備註",
+    "send an email" : "傳送電子郵件",
     "Personal dates" : "個人日期",
     "Add property of this type" : "添加此類型的屬性",
     "Member" : "成員",
